#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 versions
version:              6.0.8
visibility:           public
id:                   versions-6.0.8-IEtpDqWw2ccXgiFVO4tH
key:                  versions-6.0.8-IEtpDqWw2ccXgiFVO4tH
license:              BSD-3-Clause
maintainer:           colin@fosskers.ca
author:               Colin Woodbury
homepage:             https://github.com/fosskers/versions
synopsis:             Types and parsers for software version numbers.
description:
    A library for parsing and comparing software version numbers. We like to give
    version numbers to our software in a myriad of ways. Some ways follow strict
    guidelines for incrementing and comparison. Some follow conventional wisdom
    and are generally self-consistent. Some are just plain asinine. This library
    provides a means of parsing and comparing /any/ style of versioning, be it a
    nice Semantic Version like this:

    > 1.2.3-r1+git123

    ...or a monstrosity like this:

    > 2:10.2+0.0093r3+1-1

    Please switch to <http://semver.org Semantic Versioning> if you aren'\''t
    currently using it. It provides consistency in version incrementing and has
    the best constraints on comparisons.

    This library implements version @2.0.0@ of the SemVer spec.

category:             Data
abi:                  ea4cc8a254c723d20f216c621b7c59f1
exposed:              True
exposed-modules:      Data.Versions
import-dirs:          /usr/lib/ghc-9.6.6/site-local/versions-6.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/versions-6.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/versions-6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-versions
hs-libraries:         HSversions-6.0.8-IEtpDqWw2ccXgiFVO4tH
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-Ws19qMM2f99bApawlWBTg
    megaparsec-9.7.1-3v9USGunK8PJV50Lxdl0PB
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-versions/html/versions.haddock
haddock-html:         /usr/share/doc/haskell-versions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

